#
# spec file for package clapper
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global uuid com.github.rafostar.Clapper
%global libver 0.0
%global libsuffix 0.6.1
%global sover 0
%global gstlib Clapper

%global gst_version 1.20.0
%global gtk4_version 4.10.0
%global meson_version 0.64
%global glib2_version 2.76.0
%global adw_version 1.4.0

%bcond_without server

Name:           clapper
Version:        0.6.1
Release:        1.1
Summary:        A GNOME media player built using GJS with GTK4
Group:          Productivity/Multimedia/Video/Players
License:        GPL-3.0-or-later
URL:            https://github.com/Rafostar/clapper
Source:         %{url}/archive/refs/tags/%{version}.tar.gz#/%{name}-%{version}.tar.gz

BuildRequires:  Mesa-libGL-devel
BuildRequires:  Mesa-libGLESv3-devel
BuildRequires:  desktop-file-utils
BuildRequires:  gcc
BuildRequires:  gobject-introspection
BuildRequires:  meson >= %{meson_version}
BuildRequires:  update-desktop-files
BuildRequires:  vala
BuildRequires:  pkgconfig(gio-2.0) >= %{glib2_version}
BuildRequires:  pkgconfig(gio-unix-2.0) >= %{glib2_version}
BuildRequires:  pkgconfig(glib-2.0) >= %{glib2_version}
BuildRequires:  pkgconfig(gmodule-2.0) >= %{glib2_version}
BuildRequires:  pkgconfig(gobject-2.0) >= %{glib2_version}
BuildRequires:  pkgconfig(gobject-introspection-1.0)
BuildRequires:  pkgconfig(gstreamer-1.0) >= %{gst_version}
BuildRequires:  pkgconfig(gstreamer-audio-1.0) >= %{gst_version}
BuildRequires:  pkgconfig(gstreamer-base-1.0) >= %{gst_version}
BuildRequires:  pkgconfig(gstreamer-pbutils-1.0) >= %{gst_version}
BuildRequires:  pkgconfig(gstreamer-tag-1.0) >= %{gst_version}
BuildRequires:  pkgconfig(gstreamer-video-1.0) >= %{gst_version}
BuildRequires:  pkgconfig(gtk4) >= %{gtk4_version}
BuildRequires:  pkgconfig(libadwaita-1) >= %{adw_version}

%if %{with server}
BuildRequires:  pkgconfig(libsoup-3.0)
BuildRequires:  pkgconfig(microdns) >= 0.2.0
%endif

%define altlibver %(sed s/[.]/_/g <<< %{libver})
Requires:       lib%{name}-%{altlibver}-%{sover} = %{version}
Requires:       lib%{name}-gtk-%{altlibver}-%{sover} = %{version}

Requires:       gstreamer >= %{gst_version}
Requires:       gstreamer-plugins-bad >= %{gst_version}
Requires:       gstreamer-plugins-base >= %{gst_version}
Requires:       gstreamer-plugins-good >= %{gst_version}
# Popular video decoders
Recommends:     gstreamer-plugins-libav >= %{gst_version}
# CD Playback
Suggests:       gstreamer-plugins-ugly
# Intel/AMD video acceleration
Suggests:       gstreamer-plugins-vaapi

%global _description %{expand:
A modern media player powered by GStreamer and built for the GNOME desktop environment.}

%package -n lib%{name}-%{altlibver}-%{sover}
Summary:        Media player components
Group:          Productivity/Multimedia/Video/Players
License:        LGPL-2.1-or-later

%package -n typelib-1_0-%{gstlib}-%{altlibver}
Summary:        Introspection bindings for lib%{name}-%{altlibver}-%{sover}
Group:          System/Libraries
License:        LGPL-2.1-or-later
Requires:       lib%{name}-%{altlibver}-%{sover} = %{version}

%package -n lib%{name}-gtk-%{altlibver}-%{sover}
Summary:        GTK media player component
Group:          Productivity/Multimedia/Video/Players
License:        LGPL-2.1-or-later
Requires:       lib%{name}-%{altlibver}-%{sover} = %{version}

%package -n typelib-1_0-%{gstlib}Gtk-%{altlibver}
Summary:        Introspection bindings for lib%{name}-gtk-%{altlibver}-%{sover}
Group:          System/Libraries
License:        LGPL-2.1-or-later
Requires:       lib%{name}-gtk-%{altlibver}-%{sover} = %{version}

%package devel
Summary:        Development files for %{name}
Group:          Development/Libraries/C and C++
License:        LGPL-2.1-or-later
Requires:       lib%{name}-%{altlibver}-%{sover} = %{version}
Requires:       lib%{name}-gtk-%{altlibver}-%{sover} = %{version}

%description %{_description}

%description -n lib%{name}-%{altlibver}-%{sover} %{_description}

%description -n typelib-1_0-%{gstlib}-%{altlibver} %{_description}
This subpackage provides the GObject Introspection bindings for
lib%{name}-%{altlibver}-%{sover}.

%description -n lib%{name}-gtk-%{altlibver}-%{sover} %{_description}

%description -n typelib-1_0-%{gstlib}Gtk-%{altlibver} %{_description}
This subpackage provides the GObject Introspection bindings for
lib%{name}-gtk-%{altlibver}-%{sover}.

%description devel %{_description}

This subpackage holds the required files to compile against
lib%{name}.

%lang_package

%prep
%autosetup -p1

%build
%meson \
	-Dserver=%{?with_server:enabled}%{!?with_server:disabled} \
	%{nil}
%meson_build

%install
%meson_install
%suse_update_desktop_file %{uuid}

%find_lang %{name}-app
%find_lang %{name}-gtk

%ldconfig_scriptlets -n lib%{name}-%{altlibver}-%{sover}
%ldconfig_scriptlets -n lib%{name}-gtk-%{altlibver}-%{sover}

%check
desktop-file-validate %{buildroot}%{_datadir}/applications/%{uuid}.desktop

%files
%license COPYING-GPL
%doc README.md
%{_bindir}/%{name}
%{_datadir}/applications/%{uuid}.desktop
%{_datadir}/dbus-1/services/%{uuid}.service
%{_datadir}/glib-2.0/schemas/%{uuid}.gschema.xml
%{_datadir}/icons/hicolor/*/apps/%{uuid}*.svg
%{_datadir}/metainfo/%{uuid}.metainfo.xml
%{_datadir}/mime/packages/%{uuid}.xml

%files -n lib%{name}-%{altlibver}-%{sover}
%license COPYING-LGPL
%{_libdir}/lib%{name}-%{libver}.so.%{sover}
%{_libdir}/lib%{name}-%{libver}.so.%{libsuffix}

%{_libdir}/libgst%{name}glcontexthandler.so.%{sover}
%{_libdir}/libgst%{name}glcontexthandler.so.%{libsuffix}
%{_libdir}/gstreamer-1.0/libgst%{name}.so
%{_libdir}/%{name}-%{libver}/

%files -n typelib-1_0-%{gstlib}-%{altlibver}
%{_libdir}/girepository-1.0/%{gstlib}-%{libver}.typelib

%files -n lib%{name}-gtk-%{altlibver}-%{sover}
%license COPYING-LGPL
%{_libdir}/lib%{name}-gtk-%{libver}.so.%{sover}
%{_libdir}/lib%{name}-gtk-%{libver}.so.%{libsuffix}

%files -n typelib-1_0-%{gstlib}Gtk-%{altlibver}
%{_libdir}/girepository-1.0/%{gstlib}Gtk-%{libver}.typelib

%files devel
%{_datadir}/gir-1.0/%{gstlib}-%{libver}.gir
%{_datadir}/gir-1.0/%{gstlib}Gtk-%{libver}.gir
%{_datadir}/vala/vapi/%{name}-%{libver}.{deps,vapi}
%{_datadir}/vala/vapi/%{name}-gtk-%{libver}.{deps,vapi}
%{_includedir}/%{name}-%{libver}/
%{_libdir}/lib%{name}-%{libver}.so
%{_libdir}/lib%{name}-gtk-%{libver}.so
%{_libdir}/libgst%{name}glcontexthandler.so
%{_libdir}/pkgconfig/%{name}-%{libver}.pc
%{_libdir}/pkgconfig/%{name}-gtk-%{libver}.pc

%files lang -f %{name}-app.lang -f %{name}-gtk.lang

%changelog
* Mon Jul  1 2024 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 0.6.1:
  + Updated metainfo summary and colors
  + Complemented metainfo categories
  + Fixed wrong MARKER_NO_END value in Clapper API GIR
  + Fixed GtkWindowControls style when used within ClapperGtkVideo
    as OSD
  + Fixed crashes after GL context is destroyed
  + Fixed missing signals disconnections after dispose of
    ClapperGtkVideo
  + Fixed playback of media with missing plugins for metadata
  + Few small documentation fixes
  + Fixed problems building clapper-gtk documentation on a clean
    system
  + Fixed info window not closing when pressing "Esc" key
  + Fixed opened file content type detection (used for determining
    subtitle files)
  + Few fixes and additional checks for meson build script
  + Ensured private types before template init in ClapperGtk API
  + Enabled audio pitch correction for non-normal speed in
    ClapperGtkVideo (use "scaletempo" audio filter by default)
  + Fixed invisible status message in ClapperGtkVideo when used in
    light theme apps
  + Made transitions time in ClapperGtkBillboard widget a tad
    faster
  + Updated translations.
* Tue Apr 23 2024 Florian "sp1rit" <sp1rit@disroot.org>
- Update to version 0.6.0:
  + Clapper was basically rewritten from scratch, but the most
    significant changes to the Clapper application itself include:
  - Brand new, simplified and consistent UI
  - Player now operates on playback queue model
  - Multiple queue progression modes to choose from (consecutive,
    repeat item, carousel, shuffle)
  - New media info window (shows media information and GStreamer
    elements used to play it)
  - More dialogs and windows use libadwaita
  - Multiple new status/info overlays showing what is going and
    other messages
  - Added video buffering animation
  - Clapper will now inform users about missing GStreamer plugins
    needed for playback
  - Video chapters now appear throughout the seek bar on hover and
    while dragging slider
  - Vastly expanded MPRIS implementation
  - Integrated media discovery (see titles of queued items instead
    of URIs)
  - Expanded WebSocket server functionality (for remote playback
    control)
  - Increased maximum volume amplification level to 200%%
  - Added some new keyboard shortcuts
  - In addition to volume, now also speed and queue progression
    mode are restored on launch
  - Fixed keyboard shortcuts not being reversed (e.g. seek) in RTL
    languages
  - Toggle play moved to left mouse button, right one now opens
    context menu (which was previously hard to access)
  - Many bug fixes and QoL improvements
  + Developers using libclapper, might want to read the main
    paragraphs of the changelog, as the internals have changed
    completely: https://github.com/Rafostar/clapper/releases/tag/0.6.0
* Fri Aug 26 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 0.5.2:
  + Fix time labels display on RTL languages
  + Improved GL/GLES context automatic selection
  + Updated translations.
* Thu Jun  9 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 0.5.1:
  * A quick hotfix release. Fixes problems with new video sink on
    displays with non-100%% scaling applied.
- Changes from version 0.5.0:
  * Clapper now includes an all new and improved GStreamer video
    sink. With it, we are moving away from GLArea into using
    GdkPaintable. This already gives us slight performance
    improvement in some cases and opens new possibilities to
    improve it further at a later time. New sink now also handles
    overlaying and displaying subtitles on the GTK side of things
    (as a separate GdkTextures instead of drawing them into
    framebuffer). Old, now called "legacy" sink is still included.
    If there are any problems with the new one, you can set
    CLAPPER_USE_LEGACY_SINK=1 env to use the old one.
  * Networking was ported into libsoup3. The built-in, unfinished
    web application was removed.
  * Additionally, app now supports D-Bus launching
    (DBusActivatable).
  * Some other misc fixes and few small UI changes were also done.
  * Updated translations.
- Update libnames define to align with soname.
* Sat Feb 26 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 0.4.1:
  * Compatibility with more recent libadwaita versions
  * Toggle mute with M button alone
  * Allow handling YouTube with external GStreamer plugins
  * Fix catching errors when reading clipboard
  * Fix missing translator-credits
  * Fix missing gio-unix-2.0 dep
  * Fix playback pausing when entering fullscreen with touchscreen
  * Fix GST_PLUGIN_FEATURE_RANK env usage
  * Fix video/audio decoder change detection
  * Merge global video tags instead replacing them
  * Few other misc bug fixes
  * Updated translations.
* Mon Oct  4 2021 Bjørn Lie <bjorn.lie@gmail.com>
- Fix typelib name to follow standard in openSUSE.
* Mon Sep 13 2021 Dead Mozay <dead_mozay@opensuse.org>
- Update to version 0.4.0:
  * New and adaptive preferences window.
  * Improved open URI dialog.
  * Few small tweaks to fullscreen UI design.
  * Show current video and audio decoders in popovers
    (easy way to check if HW accel is used).
  * Enabled NVDEC hardware acceleration by default
    (requires Nvidia proprietary drivers).
  * Added option to use PipeWire for audio output (experimental).
  * Added option to use playbin3 element (experimental).
  * Improved performance on devices running OpenGL ES.
  * Translations support.
  * New keyboard shortcuts:
  - Leave fullscreen with Escape key.
  - Toggle mute with Ctrl+M.
  * More touchscreen gestures:
  - Toggle playback with a long press.
  - Switch playlist items via double tap on screen side.
  * New translations:
  - Catalan.
  - Dutch.
  - German.
  - Italian.
  - Polish.
* Fri Jun 18 2021 Dead Mozay <dead-mozay@opensuse.org>
- Update to version 0.3.0:
  * Added MPRIS support.
  * Added repeat modes: single video, whole playlist and shuffle.
  * Support opening folders with media files.
  * Append playlist items by holding Ctrl while doing Drag and Drop.
  * Improved handling of keyboard shortcuts.
  * Added more keyboard shortcuts.
  * Added window that shows available keyboard shortcuts.
  * Show black screen by default after playback
    (make showing last frame optional instead).
  * Added ability to export playlist to file.
  * Improve handling of changing displays with different resolutions.
  * Added support for EGL under x11 with GTK 4.3.1 or later.
  * Added missing symbolic app icon.
  * Some misc bug fixes and code cleanups.
* Mon Apr 19 2021 Dead Mozay <dead_mozay@opensuse.org>
- Update to version 0.2.1:
  * Fix missing top left menu buttons on some system configurations
  * Fix potential video sink deadlock
  * Do not show mobile controls transition on launch
  * Show tooltip with full playlist item text on hover
  * Auto select best matching resolution for used monitor
  * Added some YouTube related preferences
  * Added support for live HLS videos
  * Added support for non-adaptive live HLS streaming
* Fri Feb 26 2021 Dead Mozay <dead_mozay@opensuse.org>
- Initial package.
